@@ -246,7 +246,7 @@ int dellssd_write(struct block_device *device, enum ibpi_pattern ibpi)
   int mask, bus, dev, fun;
   char *t;
 
-  if ((ibpi < IBPI_PATTERN_NORMAL) || (ibpi > IBPI_PATTERN_LOCATE)) {
+  if ((ibpi < IBPI_PATTERN_NORMAL) || (ibpi > IBPI_PATTERN_LOCATE_OFF)) {
     __set_errno_and_return(ERANGE);
   }
   mask = ibpi2ssd[ibpi];
