@@ -3,7 +3,7 @@
 
 /*
  * Intel(R) Enclosure LED Utilities
- * Copyright (C) 2009,2011, Intel Corporation.
+ * Copyright (C) 2009,2011,2012, Intel Corporation.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms and conditions of the GNU General Public License,
@@ -96,7 +96,7 @@ const char *ibpi_str[] = {
  * information about the version of ledctl utility.
  */
 static char *ledctl_version = "Intel(R) Enclosure LED Control Application " \
-  "%d.%d\nCopyright (C) 2009,2011 Intel Corporation.\n";
+  "%d.%d\nCopyright (C) 2009-2012 Intel Corporation.\n";
 
 /**
  * Internal variable of monitor service. It is used to help parse command line
@@ -188,8 +188,28 @@ static void _ledctl_help(void)
          "(not yet\n\t\t\t\t  implemented).\n");
   printf("--help\t\t\t\t  Displays this help text.\n");
   printf("--version\t\t\t  Displays version and license information.\n\n");
-  printf("Refer to ledctl(8) man page for more detailed description.\n");
-  printf("Report bugs to: artur.wojcik@intel.com\n\n");
+  printf("Patterns:\n"
+		  "\tCommon patterns are: \n"
+		  "\t\tlocate, locate_off, normal, off, degraded, rebuild,\n"""
+		  "\t\trebuild_p, failed_array, hotspare, pfa, failure,\n"
+		  "\t\tdisk_failed\n"
+		  "\tSES-2 only patterns:\n"
+		  "\t\tses_abort, ses_rebuild, ses_ifa, ses_ica, ses_cons_check,\n"
+		  "\t\tses_hotspare, ses_rsvd_dev, ses_ok, ses_ident, ses_rm,\n"
+		  "\t\tses_insert, ses_missing, ses_dnr, ses_active,\n"
+		  "\t\tses_enbale_bb, ses_enable_ba, ses_devoff, ses_fault\n"
+		  "\tAutomatic translation form IBPI into SES-2:\n"
+		  "\t\tlocate=ses_ident, locate_off=~ses_ident,\n"
+		  "\t\tnormal=ses_ok, off=ses_ok, degraded=ses_ica,\n"
+		  "\t\trebuild=ses_rebuild rebuild_p=ses_rebuild,\n"
+		  "\t\tfailed_array=ses_ifa, hotspare=ses_hotspare \n"
+		  "\t\tpfa=ses_rsvd_dev, failure=ses_fault,\n"
+		  "\t\tdisk_failed=ses_fault \n");
+ 	printf("Refer to ledctl(8) man page for more detailed description.\n");
+	printf("Report bugs in the tracker 'Bugs' at " \
+		   "http://sourceforge.net/projects/ledmon\n");
+	printf("(direct link: http://sourceforge.net/tracker" \
+		   "/?group_id=393394&atid=1632895)\n\n");
 }
 
 /**
@@ -387,6 +407,42 @@ static struct ibpi_state *_ibpi_state_get(const char *name)
   } else if ((strcmp(name, "failure") == 0) ||
              (strcmp(name, "disk_failed") == 0)) {
     ibpi = IBPI_PATTERN_FAILED_DRIVE;
+  } else if (strcmp(name, "ses_abort") == 0) {
+	  ibpi = SES_REQ_ABORT;
+  } else if (strcmp(name, "ses_rebuild") == 0) {
+	  ibpi = SES_REQ_REBUILD;
+  } else if (strcmp(name, "ses_ifa") == 0) {
+	  ibpi = SES_REQ_IFA;
+  } else if (strcmp(name, "ses_ica") == 0) {
+	  ibpi = SES_REQ_ICA;
+  } else if (strcmp(name, "ses_cons_check") == 0) {
+	  ibpi = SES_REQ_CONS_CHECK;
+  } else if (strcmp(name, "ses_hotspare") == 0) {
+	  ibpi = SES_REQ_HOSTSPARE;
+  } else if (strcmp(name, "ses_rsvd_dev") == 0) {
+	  ibpi = SES_REQ_RSVD_DEV;
+  } else if (strcmp(name, "ses_ok") == 0) {
+	  ibpi = SES_REQ_OK;
+  } else if (strcmp(name, "ses_ident") == 0) {
+	  ibpi = SES_REQ_IDENT;
+  } else if (strcmp(name, "ses_rm") == 0) {
+	  ibpi = SES_REQ_RM;
+  } else if (strcmp(name, "ses_insert") == 0) {
+	  ibpi = SES_REQ_INS;
+  } else if (strcmp(name, "ses_missing") == 0) {
+	  ibpi = SES_REQ_MISSING;
+  } else if (strcmp(name, "ses_dnr") == 0) {
+	  ibpi = SES_REQ_DNR;
+  } else if (strcmp(name, "ses_active") == 0) {
+	  ibpi = SES_REQ_ACTIVE;
+  } else if (strcmp(name, "ses_enbale_bb") == 0) {
+	  ibpi = SES_REQ_EN_BB;
+  } else if (strcmp(name, "ses_enable_ba") == 0) {
+	  ibpi = SES_REQ_EN_BA;
+  } else if (strcmp(name, "ses_devoff") == 0) {
+	  ibpi = SES_REQ_DEV_OFF;
+  } else if (strcmp(name, "ses_fault") == 0) {
+	  ibpi = SES_REQ_FAULT;
   } else {
     return NULL;
   }
@@ -575,7 +631,10 @@ static status_t _cmdline_parse(int argc, char *argv[])
  */
 static void _send_cntrl_message(struct block_device *device)
 {
-  device->send_fn(device, device->ibpi);
+	/* turn off all unset LEDs */
+	if (device->ibpi == IBPI_PATTERN_UNKNOWN)
+		device->ibpi = IBPI_PATTERN_NORMAL;
+	device->send_fn(device, device->ibpi);
 }
 
 /**
