@@ -3,7 +3,7 @@
 
 /*
  * Intel(R) Enclosure LED Utilities
- * Copyright (C) 2009,2011, Intel Corporation.
+ * Copyright (C) 2009,2011,2012, Intel Corporation.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms and conditions of the GNU General Public License,
@@ -456,6 +456,23 @@ char *str_cat(char *dest, const char *src, size_t size)
   }
   return dest;
 }
+char *get_path_hostN(const char *path)
+{
+	char *c=NULL, *s=NULL, *p=strdup(path);
+	if (!p)
+		return NULL;
+	c = strstr(p, "host");
+	if (!c)
+		goto end;
+	s = strchr(c,'/');
+	if (!s)
+		goto end;
+	*s = 0;
+	s = strdup(c);
+end:
+	free(p);
+	return s;
+}
 
 char *get_path_component_rev(const char *path, int index)
 {
